==> evolution-3.1.19.zip: evolution-3.1.19/assets/plugins/updater/lang/en.php <==
<?php
// ---------------------------------------------------------------
// :: Updater
// ----------------------------------------------------------------
//
//
//
// ----------------------------------------------------------------
// :: Copyright & Licencing
// ----------------------------------------------------------------
//
//   GNU General Public License (GPL - http://www.gnu.org/copyleft/gpl.html)
//

$_lang['pluginname'] = 'Updater';
$_lang['system_update'] = 'System Update';
$_lang['are_you_sure_update'] = 'Are you sure you want to run a system update?';
$_lang["cms_outdated_msg"] = 'Content management system is outdated. To update contact the site developers. Current version';
$_lang['bkp_before_msg'] = 'We strongly recommend making a backup before upgrading the system, the update is performed at your own risk !!';
$_lang['updateButton_txt'] = 'Update to version';
$_lang['updateButtonCommit_txt'] = 'Update to this commit';
$_lang['table_commitdate'] = 'Commit Date';
$_lang['table_titleauthor'] = 'Title (Author)';
//Error Messages
$_lang['error_curl'] = 'You need to enable CURL function in PHP';
$_lang['error_zip'] = 'It is necessary to enable the ZIP in PHP';
$_lang['error_openssl'] = 'You need to enable OpenSSL function in PHP';
$_lang['error_overwrite'] = 'Evolution CMS files are not available for overwriting';
$_lang['error_failedtogetfeed'] = 'Failed to retrieve feed';

$_lang['artisan_update'] = 'For update run console command from <b>core</b> folder: <b>php artisan make:site update</b>';

==> evolution-3.1.29.zip: evolution-3.1.29/assets/plugins/updater/lang/en.php <==
<?php
// ---------------------------------------------------------------
// :: Updater
// ----------------------------------------------------------------
//
//
//
// ----------------------------------------------------------------
// :: Copyright & Licencing
// ----------------------------------------------------------------
//
//   GNU General Public License (GPL - http://www.gnu.org/copyleft/gpl.html)
//

$_lang['pluginname'] = 'Updater';
$_lang['system_update'] = 'System Update';
$_lang['are_you_sure_update'] = 'Are you sure you want to run a system update?';
$_lang["cms_outdated_msg"] = 'Content management system is outdated. To update contact the site developers. Current version';
$_lang['bkp_before_msg'] = 'We strongly recommend making a backup before upgrading the system, the update is performed at your own risk !!';
$_lang['updateButton_txt'] = 'Update to version';
$_lang['updateButtonCommit_txt'] = 'Update to this commit';
$_lang['table_commitdate'] = 'Commit Date';
$_lang['table_titleauthor'] = 'Title (Author)';
//Error Messages
$_lang['error_curl'] = 'You need to enable CURL function in PHP';
$_lang['error_zip'] = 'It is necessary to enable the ZIP in PHP';
$_lang['error_openssl'] = 'You need to enable OpenSSL function in PHP';
$_lang['error_overwrite'] = 'Evolution CMS files are not available for overwriting';
$_lang['error_failedtogetfeed'] = 'Failed to retrieve feed';

$_lang['artisan_update'] = 'For update run console command from <b>core</b> folder: <b>php artisan make:update</b>';
